<?php

namespace Btravel\Category\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Btravel\Category\Http\Requests\BtCategoryRequest;
use Btravel\Category\Interfaces\BtCategoryRepositoryInterface;
use Btravel\Category\Models\BtCategory;
use Btravel\Category\Forms\BtCategory as Form;

/**
 * APIController  class for bt_category.
 */
class BtCategoryAPIController extends BaseController
{

    /**
     * Initialize bt_category resource controller.
     *
     * @param type BtCategoryRepositoryInterface $bt_category
     *
     * @return null
     */
    public function __construct(BtCategoryRepositoryInterface $bt_category)
    {
        parent::__construct();
        $this->repository = $bt_category;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Btravel\Category\Repositories\Criteria\BtCategoryResourceCriteria::class);
    }

    /**
     * Display a list of bt_category.
     *
     * @return Response
     */
    public function index(BtCategoryRequest $request)
    {
        return $this->repository
            ->setPresenter(\Btravel\Category\Repositories\Presenter\BtCategoryPresenter::class)
            ->paginate();
    }

    /**
     * Display bt_category.
     *
     * @param Request $request
     * @param Model   $bt_category
     *
     * @return Response
     */
    public function show(BtCategoryRequest $request, BtCategory $bt_category)
    {
        return $bt_category->setPresenter(\Btravel\Category\Repositories\Presenter\BtCategoryListPresenter::class);
        ;
    }

    /**
     * Create new bt_category.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(BtCategoryRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('category::bt_category.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('category/bt_category/' . $bt_category->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('category/bt_category');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the bt_category.
     *
     * @param Request $request
     * @param Model   $bt_category
     *
     * @return Response
     */
    public function update(BtCategoryRequest $request, BtCategory $bt_category)
    {
        try {
            $data = $request->all();

            $bt_category->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('category::bt_category.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('category/bt_category/' . $bt_category->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('category/bt_category/' . $bt_category->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the bt_category.
     *
     * @param Model   $bt_category
     *
     * @return Response
     */
    public function destroy(BtCategoryRequest $request, BtCategory $bt_category)
    {
        try {
            $bt_category->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('category::bt_category.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('category/bt_category/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('category/bt_category/' . $bt_category->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
