<?php

namespace Btravel\Category\Policies;

use Litepie\User\Contracts\UserPolicy;
use Btravel\Category\Models\BtCategory;

class BtCategoryPolicy
{

    /**
     * Determine if the given user can view the bt_category.
     *
     * @param UserPolicy $user
     * @param BtCategory $bt_category
     *
     * @return bool
     */
    public function view(UserPolicy $user, BtCategory $bt_category)
    {
        if ($user->canDo('category.bt_category.view') && $user->isAdmin()) {
            return true;
        }

        return $bt_category->user_id == user_id() && $bt_category->user_type == user_type();
    }

    /**
     * Determine if the given user can create a bt_category.
     *
     * @param UserPolicy $user
     * @param BtCategory $bt_category
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('category.bt_category.create');
    }

    /**
     * Determine if the given user can update the given bt_category.
     *
     * @param UserPolicy $user
     * @param BtCategory $bt_category
     *
     * @return bool
     */
    public function update(UserPolicy $user, BtCategory $bt_category)
    {
        if ($user->canDo('category.bt_category.edit') && $user->isAdmin()) {
            return true;
        }

        return $bt_category->user_id == user_id() && $bt_category->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given bt_category.
     *
     * @param UserPolicy $user
     * @param BtCategory $bt_category
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, BtCategory $bt_category)
    {
        return $bt_category->user_id == user_id() && $bt_category->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given bt_category.
     *
     * @param UserPolicy $user
     * @param BtCategory $bt_category
     *
     * @return bool
     */
    public function verify(UserPolicy $user, BtCategory $bt_category)
    {
        if ($user->canDo('category.bt_category.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given bt_category.
     *
     * @param UserPolicy $user
     * @param BtCategory $bt_category
     *
     * @return bool
     */
    public function approve(UserPolicy $user, BtCategory $bt_category)
    {
        if ($user->canDo('category.bt_category.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
